free abstract method
- @moveSemantics
inherited
Drops the associated Rust struct and nulls the local Pointer to it.
Implementation
@moveSemantics
void free();
Drops the associated Rust struct and nulls the local Pointer to it.
@moveSemantics
void free();