LocalMediaInitException class abstract

Exception thrown when accessing media devices.

Implemented types

Constructors

LocalMediaInitException()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cause() → dynamic
Returns error that caused this LocalMediaInitException.
kind() LocalMediaInitExceptionKind
Returns concrete error kind of this LocalMediaInitException.
message() String
Returns error message describing the problem.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
trace() String
Returns stacktrace of this LocalMediaInitException.

Operators

operator ==(Object other) bool
The equality operator.
inherited