RemoteMediaTrack class abstract

Representation of a received remote MediaStreamTrack.

Implemented types

Constructors

RemoteMediaTrack()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

free() Future<void>
Drops the associated Rust struct and nulls the local Pointer to it.
inherited
getTrack() → MediaStreamTrack
Returns the underlying MediaStreamTrack of this LocalMediaTrack.
inherited
kind() MediaKind
Returns the MediaKind.Audio if this LocalMediaTrack represents an audio track, or the MediaKind.Video if it represents a video track.
inherited
mediaDirection() TrackMediaDirection
Returns the current general TrackMediaDirection of this RemoteMediaTrack.
mediaSourceKind() MediaSourceKind
Returns the MediaSourceKind.Device if this LocalMediaTrack is sourced from some device (webcam/microphone), or the MediaSourceKind.Display if it's captured via MediaDevices.getDisplayMedia().
inherited
muted() bool
Indicate whether this RemoteMediaTrack is muted.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onMediaDirectionChanged(void f(TrackMediaDirection)) → void
Sets callback to be invoked whenever this RemoteMediaTrack's general TrackMediaDirection is changed.
onMuted(void f()) → void
Sets callback to invoke when this RemoteMediaTrack is muted.
onStopped(void f()) → void
Sets callback to invoke when this RemoteMediaTrack is stopped.
onUnmuted(void f()) → void
Sets callback to invoke when this RemoteMediaTrack is unmuted.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited