AudioDeviceKind enum
Possible kinds of audio devices.
Values
- earSpeaker → const AudioDeviceKind
-
Built-in earpiece speaker.
- speakerphone → const AudioDeviceKind
-
Built-in loudspeaker.
- wiredHeadphones → const AudioDeviceKind
-
Wired headphones without microphone.
- wiredHeadset → const AudioDeviceKind
-
Wired headset with a microphone.
- usbHeadphones → const AudioDeviceKind
-
USB headphones without microphone.
- usbHeadset → const AudioDeviceKind
-
USB headset with a microphone.
- bluetoothHeadphones → const AudioDeviceKind
-
Bluetooth headphones profile (A2DP/BLE speaker).
- bluetoothHeadset → const AudioDeviceKind
-
Bluetooth headset profile suitable for calls (SCO/BLE headset).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AudioDeviceKind> - A constant List of the values in this enum, in order of their declaration.