ConnectionHandle class abstract
External handler to a Connection with a remote Member.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
disableRemoteAudio(
) → Future< void> -
Disables inbound audio in this
Connection. -
disableRemoteVideo(
[MediaSourceKind? kind]) → Future< void> -
Disables inbound video in this
Connection. -
enableRemoteAudio(
) → Future< void> -
Enables inbound audio in this
Connection. -
enableRemoteVideo(
[MediaSourceKind? kind]) → Future< void> -
Enables inbound video in this
Connection. -
free(
) → void -
Drops the associated Rust struct and nulls the local Pointer to it.
inherited
-
getRemoteMemberId(
) → String -
Returns ID of the remote
Member. -
getState(
) → MemberConnectionState? -
Returns MemberConnectionState of this
Connection. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onClose(
void f()) → void -
Sets callback, invoked when this
Connectionis closed. -
onQualityScoreUpdate(
void f(int)) → void - Sets callback, invoked when a connection quality score is updated by a server.
-
onRemoteTrackAdded(
void f(RemoteMediaTrack)) → void -
Sets callback, invoked when a new RemoteMediaTrack is added to this
Connection. -
onStateChange(
void f(MemberConnectionState)) → void -
Sets a callback to be invoked once a state of this
Connectionis changed. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited